pub struct DataflowLayout {
pub inputs: HashSet<Uuid>,
pub outputs: HashSet<Uuid>,
pub queries: HashSet<Uuid>,
pub queryables: HashSet<Uuid>,
pub labels: HashMap<Uuid, String>,
pub nodes: HashMap<Uuid, HashSet<Uuid>>,
}Expand description
Represents a flattened dataflow layout
Fields
inputs: HashSet<Uuid>Inputs present in the dataflow
outputs: HashSet<Uuid>Outputs present in the dataflow
queries: HashSet<Uuid>Queries present in the dataflow
queryables: HashSet<Uuid>Queryables present in the dataflow
labels: HashMap<Uuid, String>Labels for nodes and IO, useful for debugging and visualization
nodes: HashMap<Uuid, HashSet<Uuid>>Nodes representation with their IO, useful for debugging and visualization
Implementations
Sourceimpl DataflowLayout
impl DataflowLayout
Sourcepub async fn node<T>(
&mut self,
label: impl Into<String>,
builder_function: impl AsyncFnOnce(&mut NodeIOBuilder) -> T,
) -> (NodeLayout, T)
pub async fn node<T>( &mut self, label: impl Into<String>, builder_function: impl AsyncFnOnce(&mut NodeIOBuilder) -> T, ) -> (NodeLayout, T)
Adds a new node to the dataflow layout, providing its label and a builder function for its IO. For convenience, the node layout is returned, together with the result of the builder function.